==> fwbuilder-2.1.15.tar.gz: fwbuilder-2.1.15/src/gui/newGroupDialog.cpp <==
/* 

                          Firewall Builder

                 Copyright (C) 2003 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id: newGroupDialog.cpp,v 1.2 2004/06/07 05:38:40 vkurland Exp $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#include "config.h"
#include "global.h"
#include "utils.h"

#include "newGroupDialog.h"
#include "FWWindow.h"

#include "fwbuilder/FWObjectDatabase.h"

#include <qlineedit.h>
#include <qapplication.h>

#include <iostream>

using namespace libfwbuilder;
using namespace std;

newGroupDialog::newGroupDialog(QWidget *parent) : newGroupDialog_q(parent)
{
    fillLibraries(libs,mw->db(),true);   // only read-write libs
    obj_name->setFocus();
}

void newGroupDialog::accept()
{
/* create a group */

    if (obj_name->text().isEmpty())
    {
        app->beep();
        return;
    }
    QDialog::accept();
}

==> fwbuilder-3.0.2.tar.gz: fwbuilder-3.0.2/src/gui/newGroupDialog.cpp <==
/*

                          Firewall Builder

                 Copyright (C) 2003 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id: newGroupDialog.cpp 332 2008-07-06 20:11:03Z vadim $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#include "../../config.h"
#include "global.h"
#include "utils.h"

#include "newGroupDialog.h"
#include "FWWindow.h"

#include "fwbuilder/FWObjectDatabase.h"

#include <qlineedit.h>
#include <qapplication.h>

#include <iostream>

using namespace libfwbuilder;
using namespace std;

newGroupDialog::~newGroupDialog()
{
    delete m_dialog;
}

newGroupDialog::newGroupDialog(QWidget *parent) : QDialog(parent)
{
    m_dialog = new Ui::newGroupDialog_q;
    m_dialog->setupUi(this);

    fillLibraries(m_dialog->libs,mw->db(),true);   // only read-write libs
    m_dialog->obj_name->setFocus();
}

void newGroupDialog::accept()
{
/* create a group */

    if (m_dialog->obj_name->text().isEmpty())
    {
        app->beep();
        return;
    }
    QDialog::accept();
}
